'use strict';

const REQUEST_HOST = 'voice.dahancloud.com'
const REQUEST_PROTOCOL = 'https'
const REQUEST_PORT = 443


class VoiceClient {
	
    constructor(options) {
        let {accountSid, authToken} = options
        if (!accountSid) {
            throw new TypeError('parameter "accountSid" is required');
        }
        if (!authToken) {
            throw new TypeError('parameter "authToken" is required');
        }
		
		var timestamp = this.getTimestamp();
		this.sig = this.md5(accountSid + authToken + timestamp);
		this.auth = new Buffer(accountSid + ':' + timestamp).toString('base64');
		this.url = '/voice/submit';
		this.post_data = '';
    }

    // 发送语音, send_data为JSON对象
    sendVoice(send_data, callback) {
		this.post_data = JSON.stringify(send_data);
        var http = require(REQUEST_PROTOCOL);
		
		var req = http.request(this.getRequestOptions(), function (res) {  
			//console.log('STATUS: ' + res.code);
			//console.log('HEADERS: ' + JSON.stringify(res.headers));
			
			res.setEncoding('utf8');  
			res.on('data', function (chunk) {  
				//console.log('BODY: ' + chunk);
				
				if (res.statusCode == '200') {
					// 返回请求结果
					callback(chunk);
				} else {
					callback("{'ERROR': 'response statusCode: " + res.statusCode + "'}");
				}
			});
		});

		req.on('error', function (e) {
			//console.log("{'ERROR': 'problem with request: " + e.message + "'}");
			callback("{'ERROR': 'problem with request: " + e.message + "'}");
		});
		
		req.write(this.post_data);
		req.end();
    }
	
	// 生成请求基本参数
	getRequestOptions() {
		var options = {
			host: REQUEST_HOST,
			port: REQUEST_PORT,
			path: this.url,
			method: 'POST',
			headers: {
				'Content-Type': 'application/json;charset=utf-8',
				'Content-Length': Buffer.byteLength(this.post_data),
				'Authorization': this.auth,
				'sig': this.sig
			}
		};
		
		return options;
	}

	// 输出格式为yyyyMMddHHmmss的时间戳
	getTimestamp() {
		var nowDate = new Date();
		var year = nowDate.getFullYear();
		var month = nowDate.getMonth() + 1;
		if (month < 10) {month = '0' + month};
		var day = nowDate.getDate();
		if (day < 10) {day = '0' + day};
		var hour = nowDate.getHours();
		if (hour < 10) {hour = '0' + hour};
		var minute = nowDate.getMinutes();
		if (minute < 10) {minute = '0' + minute};
		var second = nowDate.getSeconds();
		if (second < 10) {second = '0' + second};

		return ('' + year + month + day + hour + minute + second);
	}
	
	// MD5加密
	md5(str){
		var crypto = require('crypto');
		return crypto.createHash('md5').update(str).digest('hex');
	};

}

module.exports = VoiceClient